changed debian/source/format to native

This commit is contained in:
openKylinBot 2022-05-13 20:05:33 +08:00
parent 1a17599fcc
commit 1740ad508a
11 changed files with 1 additions and 11117 deletions

View File

@ -1,21 +0,0 @@
From: TANIGUCHI Takaki <takaki@asis.media-as.org>
Date: Tue, 30 Jan 2018 13:52:33 +0900
Subject: dh-autoconf generate config files
---
configure.in | 3 ---
1 file changed, 3 deletions(-)
diff --git a/configure.in b/configure.in
index f91a782..8f940a2 100644
--- a/configure.in
+++ b/configure.in
@@ -1,8 +1,5 @@
AC_INIT(interface/interface.c)
-cp $srcdir/configure.guess $srcdir/config.guess
-cp $srcdir/configure.sub $srcdir/config.sub
-
AC_CANONICAL_HOST
if test -z "$CC"; then

View File

@ -1,450 +0,0 @@
From: A Costa <agcosta@gis.net>
Date: Tue, 30 Jan 2018 13:50:59 +0900
Subject: Fixes some typos and spelling mistakes.
Bug-Debian: http://bugs.debian.org/552209
Bug-Debian: http://bugs.debian.org/572482
Forwarded: yes
Last-Updated: 2010-11-06
---
cdparanoia.1 | 119 +++++++++++++++++++++++++++++++++++------------------------
main.c | 27 ++++++++------
2 files changed, 86 insertions(+), 60 deletions(-)
diff --git a/cdparanoia.1 b/cdparanoia.1
index cb625cc..c588403 100644
--- a/cdparanoia.1
+++ b/cdparanoia.1
@@ -1,16 +1,17 @@
.TH CDPARANOIA 1 "11 Sep 2008"
.SH NAME
-cdparanoia 10.2 (Paranoia release III) \- an audio CD reading utility which includes extra data verification features
+cdparanoia \- an audio CD reading utility which includes extra data verification features
.SH SYNOPSIS
.B cdparanoia
.RB [ options ]
.B span
.RB [ outfile ]
+.RB | \-B
.SH DESCRIPTION
.B cdparanoia
-retrieves audio tracks from CDDA capable CDROM drives. The data can
+retrieves audio tracks from CDDA-capable CDROM drives. The data can
be saved to a file or directed to standard output in WAV, AIFF, AIFF-C
-or raw format. Most ATAPI, SCSI and several proprietary CDROM drive
+or raw format. Most ATAPI and SCSI and several proprietary CDROM drive
makes are supported;
.B cdparanoia
can determine if the target drive is CDDA capable.
@@ -24,12 +25,12 @@ and scratch reconstruction capability.
.TP
.B \-A --analyze-drive
Run and log a complete analysis of drive caching, timing and reading behavior;
-verifies that cdparanoia is correctly modelling a sprcific drive's cache and
+verifies that cdparanoia is correctly modelling a specific drive's cache and
read behavior. Implies -vQL.
.TP
.B \-v --verbose
-Be absurdly verbose about the autosensing and reading process. Good
+Be absurdly verbose about the auto-sensing and reading process. Good
for setup and debugging.
.TP
@@ -46,7 +47,7 @@ Save result summary to file, default filename cdparanoia.log.
.TP
.B \-L --log-debug [file]
-Save detailed device autosense and debugging output to a file, default filename cdparanoia.log.
+Save detailed device auto-sense and debugging output to a file, default filename cdparanoia.log.
.TP
.B \-V --version
@@ -54,12 +55,12 @@ Print the program version and quit.
.TP
.B \-Q --query
-Perform CDROM drive autosense, query and print the CDROM table of
+Perform CDROM drive auto-sense, query and print the CDROM table of
contents, then quit.
.TP
.B \-s --search-for-drive
-Forces a complete search for a cdrom drive, even if the /dev/cdrom link exists.
+Forces a complete search for a CDROM drive, even if the /dev/cdrom link exists.
.TP
.B \-h --help
@@ -69,7 +70,7 @@ usage and options.
.TP
.B \-p --output-raw
-Output headerless data as raw 16 bit PCM data with interleaved samples in host byte order. To force little or big endian byte order, use
+Output headerless data as raw 16-bit PCM data with interleaved samples in host byte order. To force little or big endian byte order, use
.B \-r
or
.B \-R
@@ -77,40 +78,46 @@ as described below.
.TP
.B \-r --output-raw-little-endian
-Output headerless data as raw 16 bit PCM data with interleaved samples in LSB first byte order.
+Output headerless data as raw 16-bit PCM data with interleaved samples in LSB first byte order.
.TP
.B \-R --output-raw-big-endian
-Output headerless data as raw 16 bit PCM data with interleaved samples in MSB first byte order.
+Output headerless data as raw 16-bit PCM data with interleaved samples in MSB first byte order.
.TP
.B \-w --output-wav
Output data in Micro$oft RIFF WAV format (note that WAV data is always
-LSB first byte order).
+LSB-first byte order).
.TP
.B \-f --output-aiff
Output data in Apple AIFF format (note that AIFC data is
-always in MSB first byte order).
+always in MSB-first byte order).
.TP
.B \-a --output-aifc
Output data in uncompressed Apple AIFF-C format (note that AIFF-C data is
-always in MSB first byte order).
+always in MSB-first byte order).
.TP
.BI "\-B --batch "
-Cdda2wav-style batch output flag; cdparanoia will split the output
+Cdda2wav-style batch output flag;
+.B cdparanoia
+will split the output
into multiple files at track boundaries. Output file names are
prepended with 'track#.'
.TP
.B \-c --force-cdrom-little-endian
Some CDROM drives misreport their endianness (or do not report it at
-all); it's possible that cdparanoia will guess wrong. Use
+all); it's possible that
+.B cdparanoia
+will guess wrong. Use
.B \-c
-to force cdparanoia to treat the drive as a little endian device.
+to force
+.B cdparanoia
+to treat the drive as a little endian device.
.TP
.B \-C --force-cdrom-big-endian
@@ -122,7 +129,7 @@ Force the interface backend to do atomic reads of
.B n
sectors per read. This number can be misleading; the kernel will often
split read requests into multiple atomic reads (the automated Paranoia
-code is aware of this) or allow reads only wihin a restricted size
+code is aware of this) or allow reads only within a restricted size
range.
.B This option should generally not be used.
@@ -131,13 +138,13 @@ range.
Force the interface backend to read from
.B device
rather than the first readable CDROM drive it finds. This can be used
-to specify devices of any valid interface type (ATAPI, SCSI or
+to specify devices of any valid interface type (ATAPI, SCSI, or
proprietary).
.TP
.BI "\-k --force-cooked-device " device
This option forces use of the old 'cooked ioctl' kernel
-interface with the specified cdrom device. The cooked ioctl interface
+interface with the specified CDROM device. The cooked ioctl interface
is obsolete in Linux 2.6 if it is present at all.
.B \-k
cannot be used
@@ -149,22 +156,22 @@ or
.TP
.BI "\-g --force-generic-device " device
-This option forces use of the old 'generic scsi' (sg) kernel
-interface with the specified generic scsi device.
+This option forces use of the old 'generic SCSI' (sg) kernel
+interface with the specified generic SCSI device.
.B \-g
cannot be used with
.BR \-k .
.B \-g
may be used with
.B \-d
-to explicitly set both the SCSI cdrom and
-generic (sg) devices seperately. This option is only useful on
-obsolete SCSI setups and when using the generic scsi (sg) driver.
+to explicitly set both the SCSI carom and
+generic (sg) devices separately. This option is only useful on
+obsolete SCSI setups and when using the generic SCSI (sg) driver.
.TP
.BI "\-S --force-read-speed " number
Use this option explicitly to set the read rate of the CD drive (where
-supported). This can reduce underruns on machines with slow disks, or
+supported). This can reduce underruns on machines that have slow disks, or
which are low on memory.
.TP
@@ -184,16 +191,19 @@ every track seeming to start too late (losing a bit of the beginning
and catching a bit of the next track).
.B \-T
accounts for this behavior. Note that this option will cause
-cdparanoia to attempt to read sectors before or past the known user
+.B cdparanoia
+to attempt to read sectors before or past the known user
data area of the disc, resulting in read errors at disc edges on most
drives and possibly even hard lockups on some buggy hardware.
.TP
.BI "\-O --sample-offset " number
Use this option to force the entire disc to shift sample position
-output by the given amount; This can be used to shift track boundaries
+output by the given amount; this can be used to shift track boundaries
for the whole disc manually on sample granularity. Note that this will
-cause cdparanoia to attempt to read partial sectors before or past the
+cause
+.B cdparanoia
+to attempt to read partial sectors before or past the
known user data area of the disc, probably causing read errors on most
drives and possibly even hard lockups on some buggy hardware.
@@ -202,8 +212,11 @@ drives and possibly even hard lockups on some buggy hardware.
.B \-Z --disable-paranoia
Disable
.B all
-data verification and correction features. When using -Z, cdparanoia
-reads data exactly as would cdda2wav with an overlap setting of zero.
+data verification and correction features. When using -Z,
+.B cdparanoia
+reads data exactly as would
+.BR cdda2wav (1)
+with an overlap setting of zero.
This option implies that
.B \-Y
is active.
@@ -211,7 +224,9 @@ is active.
.TP
.B \-z --never-skip[=max_retries]
Do not accept any skips; retry forever if needed. An optional maximum
-number of retries can be specified; for comparison, default without -z is
+number of retries can be specified; for comparison, default without
+.B -z
+is
currently 20.
.TP
@@ -221,7 +236,7 @@ boundaries is performed. It can wedge if errors occur in the attempted overlap a
.TP
.B \-X --abort-on-skip
-If the read skips due to imperfect data, a scratch, whatever, abort reading this track. If output is to a file, delete the partially completed file.
+If the read skips due to imperfect data, a scratch, or whatever, abort reading this track. If output is to a file, delete the partially completed file.
.SH OUTPUT SMILIES
.TP
@@ -282,7 +297,9 @@ Unreported loss of streaming/other error in read
.B
!
Errors found after stage 1 correction; the drive is making the
-same error through multiple re-reads, and cdparanoia is having trouble
+same error through multiple re-reads, and
+.B cdparanoia
+is having trouble
detecting them.
.TP
.B
@@ -295,8 +312,9 @@ Uncorrected error/skip
.SH SPAN ARGUMENT
-The span argument specifies which track, tracks or subsections of
-tracks to read. This argument is required.
+The span argument specifies which track, tracks, or subsections of
+tracks to read. This argument is required,
+unless batch-mode is used (in batch-mode, cdparanoia will rip all tracks if no span is given).
.B NOTE:
Unless the span is a simple number, it's generally a good idea to
quote the span argument to protect it from the shell.
@@ -307,7 +325,7 @@ specification. The syntax of an offset/span takes the rough form:
1[ww:xx:yy.zz]-2[aa:bb:cc.dd]
.P
Here, 1 and 2 are track numbers; the numbers in brackets provide a
-finer grained offset within a particular track. [aa:bb:cc.dd] is in
+finer-grained offset within a particular track. [aa:bb:cc.dd] is in
hours/minutes/seconds/sectors format. Zero fields need not be
specified: [::20], [:20], [20], [20.], etc, would be interpreted as
twenty seconds, [10:] would be ten minutes, [.30] would be thirty
@@ -315,7 +333,7 @@ sectors (75 sectors per second).
.P
When only a single offset is supplied, it is interpreted as a starting
offset and ripping will continue to the end of the track. If a single
-offset is preceeded or followed by a hyphen, the implicit missing
+offset is preceded or followed by a hyphen, the implicit missing
offset is taken to be the start or end of the disc, respectively. Thus:
.TP
@@ -335,18 +353,18 @@ Specifies ripping from the beginning of the disc up to 2:[30.35]
.B 2-4
Specifies ripping from the beginning of track 2 to the end of track 4.
.P
-Again, don't forget to protect square brackets and preceeding hyphens from
+Again, don't forget to protect square brackets from
the shell.
.SH EXAMPLES
A few examples, protected from the shell:
.TP
-Query only with exhaustive search for a drive and full reporting of autosense:
+Query only with exhaustive search for a drive and full reporting of auto-sense:
.P
cdparanoia -vsQ
.TP
-Extract an entire disc, putting each track in a seperate file:
+Extract an entire disc, putting each track in a separate file:
.P
cdparanoia -B
.TP
@@ -354,26 +372,30 @@ Extract from track 1, time 0:30.12 to 1:10.00:
.P
cdparanoia "1[:30.12]-1[1:10]"
.TP
-Extract from the beginning of the disc up to track 3:
+Extract from the beginning of the disc up through track 3:
.P
- cdparanoia -- "-3"
+ cdparanoia -- -3
.TP
The "--" above is to distinguish "-3" from an option flag.
.SH OUTPUT
The output file argument is optional; if it is not specified,
-cdparanoia will output samples to one of
+.B cdparanoia
+will output samples to one of
.BR cdda.wav ", " cdda.aifc ", or " cdda.raw
depending on whether
-.BR \-w ", " \-a ", " \-r " or " \-R " is used (" \-w
+.BR \-w ", " \-a ", " \-r " or, " \-R " is used (" \-w
is the implicit default). The output file argument of
.B \-
specifies standard output; all data formats may be piped.
.SH ACKNOWLEDGEMENTS
-Cdparanoia sprang from and once drew heavily from the interface of
+.B cdparanoia
+sprang from and once drew heavily from the interface of
Heiko Eissfeldt's (heiko@colossus.escape.de) 'cdda2wav'
-package. Cdparanoia would not have happened without it.
+package.
+.B cdparanoia
+would not have happened without it.
.P
Joerg Schilling has also contributed SCSI expertise through his
generic SCSI transport library.
@@ -381,5 +403,6 @@ generic SCSI transport library.
.SH AUTHOR
Monty <monty@xiph.org>
.P
-Cdparanoia's homepage may be found at:
+.B cdparanoia's
+homepage may be found at:
http://www.xiph.org/paranoia/
diff --git a/interface/scan_devices.c b/interface/scan_devices.c
index fc58110..dc04da2 100644
--- a/interface/scan_devices.c
+++ b/interface/scan_devices.c
@@ -179,6 +179,12 @@ cdrom_drive *cdda_identify_cooked(const char *dev, int messagedest,
case IDE1_MAJOR:
case IDE2_MAJOR:
case IDE3_MAJOR:
+ case IDE4_MAJOR:
+ case IDE5_MAJOR:
+ case IDE6_MAJOR:
+ case IDE7_MAJOR:
+ case IDE8_MAJOR:
+ case IDE9_MAJOR:
/* Yay, ATAPI... */
/* Ping for CDROM-ness */

View File

@ -1,597 +0,0 @@
From: Monty <paranoia@xiph.org>
Date: Tue, 30 Jan 2018 13:51:00 +0900
Subject: Changeset 15338: Commit fix for 'private' becoming a reserved
keyword as of
GCC 4.3+ (Closes: #499676).
---
interface/cdda_interface.h | 2 +-
interface/cooked_interface.c | 8 +--
interface/interface.c | 8 +--
interface/scan_devices.c | 22 ++++----
interface/scsi_interface.c | 128 +++++++++++++++++++++----------------------
interface/test_interface.c | 4 +-
6 files changed, 86 insertions(+), 86 deletions(-)
diff --git a/interface/cdda_interface.h b/interface/cdda_interface.h
index 8487cb7..c97d160 100644
--- a/interface/cdda_interface.h
+++ b/interface/cdda_interface.h
@@ -84,7 +84,7 @@ typedef struct cdrom_drive{
int is_atapi;
int is_mmc;
- cdda_private_data_t *private;
+ cdda_private_data_t *private_data;
void *reserved;
unsigned char inqbytes[4];
diff --git a/interface/cooked_interface.c b/interface/cooked_interface.c
index de29055..3eea58c 100644
--- a/interface/cooked_interface.c
+++ b/interface/cooked_interface.c
@@ -13,13 +13,13 @@
static int timed_ioctl(cdrom_drive *d, int fd, int command, void *arg){
struct timespec tv1;
struct timespec tv2;
- int ret1=clock_gettime(d->private->clock,&tv1);
+ int ret1=clock_gettime(d->private_data->clock,&tv1);
int ret2=ioctl(fd, command,arg);
- int ret3=clock_gettime(d->private->clock,&tv2);
+ int ret3=clock_gettime(d->private_data->clock,&tv2);
if(ret1<0 || ret3<0){
- d->private->last_milliseconds=-1;
+ d->private_data->last_milliseconds=-1;
}else{
- d->private->last_milliseconds = (tv2.tv_sec-tv1.tv_sec)*1000. + (tv2.tv_nsec-tv1.tv_nsec)/1000000.;
+ d->private_data->last_milliseconds = (tv2.tv_sec-tv1.tv_sec)*1000. + (tv2.tv_nsec-tv1.tv_nsec)/1000000.;
}
return ret2;
}
diff --git a/interface/interface.c b/interface/interface.c
index e8a90cd..cce83a4 100644
--- a/interface/interface.c
+++ b/interface/interface.c
@@ -39,9 +39,9 @@ int cdda_close(cdrom_drive *d){
if(d->drive_model)free(d->drive_model);
if(d->cdda_fd!=-1)close(d->cdda_fd);
if(d->ioctl_fd!=-1 && d->ioctl_fd!=d->cdda_fd)close(d->ioctl_fd);
- if(d->private){
- if(d->private->sg_hd)free(d->private->sg_hd);
- free(d->private);
+ if(d->private_data){
+ if(d->private_data->sg_hd)free(d->private_data->sg_hd);
+ free(d->private_data);
}
free(d);
@@ -127,7 +127,7 @@ long cdda_read_timed(cdrom_drive *d, void *buffer, long beginsector, long sector
}
}
}
- if(ms)*ms=d->private->last_milliseconds;
+ if(ms)*ms=d->private_data->last_milliseconds;
return(sectors);
}
diff --git a/interface/scan_devices.c b/interface/scan_devices.c
index dc04da2..fd3355d 100644
--- a/interface/scan_devices.c
+++ b/interface/scan_devices.c
@@ -270,11 +270,11 @@ cdrom_drive *cdda_identify_cooked(const char *dev, int messagedest,
d->interface=COOKED_IOCTL;
d->bigendianp=-1; /* We don't know yet... */
d->nsectors=-1;
- d->private=calloc(1,sizeof(*d->private));
+ d->private_data=calloc(1,sizeof(*d->private_data));
{
/* goddamnit */
struct timespec tv;
- d->private->clock=(clock_gettime(CLOCK_MONOTONIC,&tv)<0?CLOCK_REALTIME:CLOCK_MONOTONIC);
+ d->private_data->clock=(clock_gettime(CLOCK_MONOTONIC,&tv)<0?CLOCK_REALTIME:CLOCK_MONOTONIC);
}
idmessage(messagedest,messages,"\t\tCDROM sensed: %s\n",description);
return(d);
@@ -680,15 +680,15 @@ cdrom_drive *cdda_identify_scsi(const char *generic_device,
d->bigendianp=-1; /* We don't know yet... */
d->nsectors=-1;
d->messagedest = messagedest;
- d->private=calloc(1,sizeof(*d->private));
+ d->private_data=calloc(1,sizeof(*d->private_data));
{
/* goddamnit */
struct timespec tv;
- d->private->clock=(clock_gettime(CLOCK_MONOTONIC,&tv)<0?CLOCK_REALTIME:CLOCK_MONOTONIC);
+ d->private_data->clock=(clock_gettime(CLOCK_MONOTONIC,&tv)<0?CLOCK_REALTIME:CLOCK_MONOTONIC);
}
if(use_sgio){
d->interface=SGIO_SCSI;
- d->private->sg_buffer=(unsigned char *)(d->private->sg_hd=malloc(MAX_BIG_BUFF_SIZE));
+ d->private_data->sg_buffer=(unsigned char *)(d->private_data->sg_hd=malloc(MAX_BIG_BUFF_SIZE));
g_fd=d->cdda_fd=dup(d->ioctl_fd);
}else{
version=verify_SG_version(d,messagedest,messages);
@@ -702,8 +702,8 @@ cdrom_drive *cdda_identify_scsi(const char *generic_device,
}
/* malloc our big buffer for scsi commands */
- d->private->sg_hd=malloc(MAX_BIG_BUFF_SIZE);
- d->private->sg_buffer=((unsigned char *)d->private->sg_hd)+SG_OFF;
+ d->private_data->sg_hd=malloc(MAX_BIG_BUFF_SIZE);
+ d->private_data->sg_buffer=((unsigned char *)d->private_data->sg_hd)+SG_OFF;
}
{
@@ -778,9 +778,9 @@ cdda_identify_scsi_fail:
if(i_fd!=-1)close(i_fd);
if(g_fd!=-1)close(g_fd);
if(d){
- if(d->private){
- if(d->private->sg_hd)free(d->private->sg_hd);
- free(d->private);
+ if(d->private_data){
+ if(d->private_data->sg_hd)free(d->private_data->sg_hd);
+ free(d->private_data);
}
free(d);
}
@@ -827,7 +827,7 @@ cdrom_drive *cdda_identify_test(const char *filename, int messagedest,
d->interface=TEST_INTERFACE;
d->bigendianp=-1; /* We don't know yet... */
d->nsectors=-1;
- d->private=calloc(1,sizeof(*d->private));
+ d->private_data=calloc(1,sizeof(*d->private_data));
d->drive_model=copystring("File based test interface");
idmessage(messagedest,messages,"\t\tCDROM sensed: %s\n",d->drive_model);
diff --git a/interface/scsi_interface.c b/interface/scsi_interface.c
index adbb9bf..b9cd96d 100644
--- a/interface/scsi_interface.c
+++ b/interface/scsi_interface.c
@@ -15,13 +15,13 @@
static int timed_ioctl(cdrom_drive *d, int fd, int command, void *arg){
struct timespec tv1;
struct timespec tv2;
- int ret1=clock_gettime(d->private->clock,&tv1);
+ int ret1=clock_gettime(d->private_data->clock,&tv1);
int ret2=ioctl(fd, command,arg);
- int ret3=clock_gettime(d->private->clock,&tv2);
+ int ret3=clock_gettime(d->private_data->clock,&tv2);
if(ret1<0 || ret3<0){
- d->private->last_milliseconds=-1;
+ d->private_data->last_milliseconds=-1;
}else{
- d->private->last_milliseconds = (tv2.tv_sec-tv1.tv_sec)*1000. + (tv2.tv_nsec-tv1.tv_nsec)/1000000.;
+ d->private_data->last_milliseconds = (tv2.tv_sec-tv1.tv_sec)*1000. + (tv2.tv_nsec-tv1.tv_nsec)/1000000.;
}
return ret2;
}
@@ -96,7 +96,7 @@ static void tweak_SG_buffer(cdrom_drive *d) {
static void clear_garbage(cdrom_drive *d){
fd_set fdset;
struct timeval tv;
- struct sg_header *sg_hd=d->private->sg_hd;
+ struct sg_header *sg_hd=d->private_data->sg_hd;
int flag=0;
/* clear out any possibly preexisting garbage */
@@ -185,7 +185,7 @@ static int sg2_handle_scsi_cmd(cdrom_drive *d,
struct timespec tv2;
int tret1,tret2;
int status = 0;
- struct sg_header *sg_hd=d->private->sg_hd;
+ struct sg_header *sg_hd=d->private_data->sg_hd;
long writebytes=SG_OFF+cmd_len+in_size;
/* generic scsi device services */
@@ -195,7 +195,7 @@ static int sg2_handle_scsi_cmd(cdrom_drive *d,
memset(sg_hd,0,sizeof(sg_hd));
memset(sense_buffer,0,SG_MAX_SENSE);
- memcpy(d->private->sg_buffer,cmd,cmd_len+in_size);
+ memcpy(d->private_data->sg_buffer,cmd,cmd_len+in_size);
sg_hd->twelve_byte = cmd_len == 12;
sg_hd->result = 0;
sg_hd->reply_len = SG_OFF + out_size;
@@ -209,7 +209,7 @@ static int sg2_handle_scsi_cmd(cdrom_drive *d,
tell if the command failed. Scared yet? */
if(bytecheck && out_size>in_size){
- memset(d->private->sg_buffer+cmd_len+in_size,bytefill,out_size-in_size);
+ memset(d->private_data->sg_buffer+cmd_len+in_size,bytefill,out_size-in_size);
/* the size does not remove cmd_len due to the way the kernel
driver copies buffers */
writebytes+=(out_size-in_size);
@@ -243,7 +243,7 @@ static int sg2_handle_scsi_cmd(cdrom_drive *d,
}
sigprocmask (SIG_BLOCK, &(d->sigset), NULL );
- tret1=clock_gettime(d->private->clock,&tv1);
+ tret1=clock_gettime(d->private_data->clock,&tv1);
errno=0;
status = write(d->cdda_fd, sg_hd, writebytes );
@@ -289,7 +289,7 @@ static int sg2_handle_scsi_cmd(cdrom_drive *d,
}
}
- tret2=clock_gettime(d->private->clock,&tv2);
+ tret2=clock_gettime(d->private_data->clock,&tv2);
errno=0;
status = read(d->cdda_fd, sg_hd, SG_OFF + out_size);
sigprocmask ( SIG_UNBLOCK, &(d->sigset), NULL );
@@ -313,7 +313,7 @@ static int sg2_handle_scsi_cmd(cdrom_drive *d,
if(bytecheck && in_size+cmd_len<out_size){
long i,flag=0;
for(i=in_size;i<out_size;i++)
- if(d->private->sg_buffer[i]!=bytefill){
+ if(d->private_data->sg_buffer[i]!=bytefill){
flag=1;
break;
}
@@ -326,9 +326,9 @@ static int sg2_handle_scsi_cmd(cdrom_drive *d,
errno=0;
if(tret1<0 || tret2<0){
- d->private->last_milliseconds=-1;
+ d->private_data->last_milliseconds=-1;
}else{
- d->private->last_milliseconds = (tv2.tv_sec-tv1.tv_sec)*1000 + (tv2.tv_nsec-tv1.tv_nsec)/1000000;
+ d->private_data->last_milliseconds = (tv2.tv_sec-tv1.tv_sec)*1000 + (tv2.tv_nsec-tv1.tv_nsec)/1000000;
}
return(0);
}
@@ -347,7 +347,7 @@ static int sgio_handle_scsi_cmd(cdrom_drive *d,
memset(&hdr,0,sizeof(hdr));
memset(sense,0,sizeof(sense));
- memcpy(d->private->sg_buffer,cmd+cmd_len,in_size);
+ memcpy(d->private_data->sg_buffer,cmd+cmd_len,in_size);
hdr.cmdp = cmd;
hdr.cmd_len = cmd_len;
@@ -355,7 +355,7 @@ static int sgio_handle_scsi_cmd(cdrom_drive *d,
hdr.mx_sb_len = SG_MAX_SENSE;
hdr.timeout = 50000;
hdr.interface_id = 'S';
- hdr.dxferp = d->private->sg_buffer;
+ hdr.dxferp = d->private_data->sg_buffer;
hdr.flags = SG_FLAG_DIRECT_IO; /* direct IO if we can get it */
/* scary buffer fill hack */
@@ -400,7 +400,7 @@ static int sgio_handle_scsi_cmd(cdrom_drive *d,
if(bytecheck && in_size<out_size){
long i,flag=0;
for(i=in_size;i<out_size;i++)
- if(d->private->sg_buffer[i]!=bytefill){
+ if(d->private_data->sg_buffer[i]!=bytefill){
flag=1;
break;
}
@@ -412,7 +412,7 @@ static int sgio_handle_scsi_cmd(cdrom_drive *d,
}
/* Can't rely on .duration because we can't be certain kernel has HZ set to something useful */
- /* d->private->last_milliseconds = hdr.duration; */
+ /* d->private_data->last_milliseconds = hdr.duration; */
errno = 0;
return 0;
@@ -445,9 +445,9 @@ static int test_unit_ready(cdrom_drive *d){
handle_scsi_cmd(d, cmd, 6, 0, 56, 0,0, sense);
- key = d->private->sg_buffer[2] & 0xf;
- ASC = d->private->sg_buffer[12];
- ASCQ = d->private->sg_buffer[13];
+ key = d->private_data->sg_buffer[2] & 0xf;
+ ASC = d->private_data->sg_buffer[12];
+ ASCQ = d->private_data->sg_buffer[13];
if(key == 2 && ASC == 4 && ASCQ == 1) return 0;
return 1;
@@ -492,7 +492,7 @@ static int mode_sense_atapi(cdrom_drive *d,int size,int page){
if (handle_scsi_cmd (d, cmd, 10, 0, size+4,'\377',1,sense)) return(1);
{
- unsigned char *b=d->private->sg_buffer;
+ unsigned char *b=d->private_data->sg_buffer;
if(b[0])return(1); /* Handles only up to 256 bytes */
if(b[6])return(1); /* Handles only up to 256 bytes */
@@ -604,8 +604,8 @@ static int mode_select(cdrom_drive *d,int density,int secsize){
static unsigned int get_orig_sectorsize(cdrom_drive *d){
if(mode_sense(d,12,0x01))return(-1);
- d->orgdens = d->private->sg_buffer[4];
- return(d->orgsize = ((int)(d->private->sg_buffer[10])<<8)+d->private->sg_buffer[11]);
+ d->orgdens = d->private_data->sg_buffer[4];
+ return(d->orgsize = ((int)(d->private_data->sg_buffer[10])<<8)+d->private_data->sg_buffer[11]);
}
/* switch CDROM scsi drives to given sector size */
@@ -664,8 +664,8 @@ static int scsi_read_toc (cdrom_drive *d){
return(-4);
}
- first=d->private->sg_buffer[2];
- last=d->private->sg_buffer[3];
+ first=d->private_data->sg_buffer[2];
+ last=d->private_data->sg_buffer[3];
tracks=last-first+1;
if (last > MAXTRK || first > MAXTRK || last<0 || first<0) {
@@ -683,7 +683,7 @@ static int scsi_read_toc (cdrom_drive *d){
return(-5);
}
{
- scsi_TOC *toc=(scsi_TOC *)(d->private->sg_buffer+4);
+ scsi_TOC *toc=(scsi_TOC *)(d->private_data->sg_buffer+4);
d->disc_toc[i-first].bFlags=toc->bFlags;
d->disc_toc[i-first].bTrack=i;
@@ -704,7 +704,7 @@ static int scsi_read_toc (cdrom_drive *d){
return(-2);
}
{
- scsi_TOC *toc=(scsi_TOC *)(d->private->sg_buffer+4);
+ scsi_TOC *toc=(scsi_TOC *)(d->private_data->sg_buffer+4);
d->disc_toc[i-first].bFlags=toc->bFlags;
d->disc_toc[i-first].bTrack=0xAA;
@@ -738,7 +738,7 @@ static int scsi_read_toc2 (cdrom_drive *d){
}
/* copy to our structure and convert start sector */
- tracks = d->private->sg_buffer[1];
+ tracks = d->private_data->sg_buffer[1];
if (tracks > MAXTRK) {
cderror(d,"003: CDROM reporting illegal number of tracks\n");
return(-3);
@@ -754,33 +754,33 @@ static int scsi_read_toc2 (cdrom_drive *d){
return(-5);
}
- d->disc_toc[i].bFlags = d->private->sg_buffer[10];
+ d->disc_toc[i].bFlags = d->private_data->sg_buffer[10];
d->disc_toc[i].bTrack = i + 1;
d->disc_toc[i].dwStartSector= d->adjust_ssize *
- (((signed char)(d->private->sg_buffer[2])<<24) |
- (d->private->sg_buffer[3]<<16)|
- (d->private->sg_buffer[4]<<8)|
- (d->private->sg_buffer[5]));
+ (((signed char)(d->private_data->sg_buffer[2])<<24) |
+ (d->private_data->sg_buffer[3]<<16)|
+ (d->private_data->sg_buffer[4]<<8)|
+ (d->private_data->sg_buffer[5]));
}
d->disc_toc[i].bFlags = 0;
d->disc_toc[i].bTrack = i + 1;
- memcpy (&foo, d->private->sg_buffer+2, 4);
- memcpy (&bar, d->private->sg_buffer+6, 4);
+ memcpy (&foo, d->private_data->sg_buffer+2, 4);
+ memcpy (&bar, d->private_data->sg_buffer+6, 4);
d->disc_toc[i].dwStartSector = d->adjust_ssize * (be32_to_cpu(foo) +
be32_to_cpu(bar));
d->disc_toc[i].dwStartSector= d->adjust_ssize *
- ((((signed char)(d->private->sg_buffer[2])<<24) |
- (d->private->sg_buffer[3]<<16)|
- (d->private->sg_buffer[4]<<8)|
- (d->private->sg_buffer[5]))+
+ ((((signed char)(d->private_data->sg_buffer[2])<<24) |
+ (d->private_data->sg_buffer[3]<<16)|
+ (d->private_data->sg_buffer[4]<<8)|
+ (d->private_data->sg_buffer[5]))+
- ((((signed char)(d->private->sg_buffer[6])<<24) |
- (d->private->sg_buffer[7]<<16)|
- (d->private->sg_buffer[8]<<8)|
- (d->private->sg_buffer[9]))));
+ ((((signed char)(d->private_data->sg_buffer[6])<<24) |
+ (d->private_data->sg_buffer[7]<<16)|
+ (d->private_data->sg_buffer[8]<<8)|
+ (d->private_data->sg_buffer[9]))));
d->cd_extra = FixupTOC(d,tracks+1);
@@ -817,7 +817,7 @@ static int i_read_28 (cdrom_drive *d, void *p, long begin, long sectors, unsigne
cmd[8] = sectors;
if((ret=handle_scsi_cmd(d,cmd,10,0,sectors * CD_FRAMESIZE_RAW,'\177',1,sense)))
return(ret);
- if(p)memcpy(p,d->private->sg_buffer,sectors*CD_FRAMESIZE_RAW);
+ if(p)memcpy(p,d->private_data->sg_buffer,sectors*CD_FRAMESIZE_RAW);
return(0);
}
@@ -836,7 +836,7 @@ static int i_read_A8 (cdrom_drive *d, void *p, long begin, long sectors, unsigne
cmd[9] = sectors;
if((ret=handle_scsi_cmd(d,cmd,12,0,sectors * CD_FRAMESIZE_RAW,'\177',1,sense)))
return(ret);
- if(p)memcpy(p,d->private->sg_buffer,sectors*CD_FRAMESIZE_RAW);
+ if(p)memcpy(p,d->private_data->sg_buffer,sectors*CD_FRAMESIZE_RAW);
return(0);
}
@@ -854,7 +854,7 @@ static int i_read_D4_10 (cdrom_drive *d, void *p, long begin, long sectors, unsi
cmd[8] = sectors;
if((ret=handle_scsi_cmd(d,cmd,10,0,sectors * CD_FRAMESIZE_RAW,'\177',1,sense)))
return(ret);
- if(p)memcpy(p,d->private->sg_buffer,sectors*CD_FRAMESIZE_RAW);
+ if(p)memcpy(p,d->private_data->sg_buffer,sectors*CD_FRAMESIZE_RAW);
return(0);
}
@@ -872,7 +872,7 @@ static int i_read_D4_12 (cdrom_drive *d, void *p, long begin, long sectors, unsi
cmd[9] = sectors;
if((ret=handle_scsi_cmd(d,cmd,12,0,sectors * CD_FRAMESIZE_RAW,'\177',1,sense)))
return(ret);
- if(p)memcpy(p,d->private->sg_buffer,sectors*CD_FRAMESIZE_RAW);
+ if(p)memcpy(p,d->private_data->sg_buffer,sectors*CD_FRAMESIZE_RAW);
return(0);
}
@@ -890,7 +890,7 @@ static int i_read_D5 (cdrom_drive *d, void *p, long begin, long sectors, unsigne
cmd[8] = sectors;
if((ret=handle_scsi_cmd(d,cmd,10,0,sectors * CD_FRAMESIZE_RAW,'\177',1,sense)))
return(ret);
- if(p)memcpy(p,d->private->sg_buffer,sectors*CD_FRAMESIZE_RAW);
+ if(p)memcpy(p,d->private_data->sg_buffer,sectors*CD_FRAMESIZE_RAW);
return(0);
}
@@ -908,7 +908,7 @@ static int i_read_D8 (cdrom_drive *d, void *p, long begin, long sectors, unsigne
cmd[9] = sectors;
if((ret=handle_scsi_cmd(d,cmd,12,0,sectors * CD_FRAMESIZE_RAW,'\177',1,sense)))
return(ret);
- if(p)memcpy(p,d->private->sg_buffer,sectors*CD_FRAMESIZE_RAW);
+ if(p)memcpy(p,d->private_data->sg_buffer,sectors*CD_FRAMESIZE_RAW);
return(0);
}
@@ -922,7 +922,7 @@ static int i_read_mmc (cdrom_drive *d, void *p, long begin, long sectors, unsign
cmd[8] = sectors;
if((ret=handle_scsi_cmd(d,cmd,12,0,sectors * CD_FRAMESIZE_RAW,'\177',1,sense)))
return(ret);
- if(p)memcpy(p,d->private->sg_buffer,sectors*CD_FRAMESIZE_RAW);
+ if(p)memcpy(p,d->private_data->sg_buffer,sectors*CD_FRAMESIZE_RAW);
return(0);
}
@@ -936,7 +936,7 @@ static int i_read_mmcB (cdrom_drive *d, void *p, long begin, long sectors, unsig
cmd[8] = sectors;
if((ret=handle_scsi_cmd(d,cmd,12,0,sectors * CD_FRAMESIZE_RAW,'\177',1,sense)))
return(ret);
- if(p)memcpy(p,d->private->sg_buffer,sectors*CD_FRAMESIZE_RAW);
+ if(p)memcpy(p,d->private_data->sg_buffer,sectors*CD_FRAMESIZE_RAW);
return(0);
}
@@ -950,7 +950,7 @@ static int i_read_mmc2 (cdrom_drive *d, void *p, long begin, long sectors, unsig
cmd[8] = sectors;
if((ret=handle_scsi_cmd(d,cmd,12,0,sectors * CD_FRAMESIZE_RAW,'\177',1,sense)))
return(ret);
- if(p)memcpy(p,d->private->sg_buffer,sectors*CD_FRAMESIZE_RAW);
+ if(p)memcpy(p,d->private_data->sg_buffer,sectors*CD_FRAMESIZE_RAW);
return(0);
}
@@ -964,7 +964,7 @@ static int i_read_mmc2B (cdrom_drive *d, void *p, long begin, long sectors, unsi
cmd[8] = sectors;
if((ret=handle_scsi_cmd(d,cmd,12,0,sectors * CD_FRAMESIZE_RAW,'\177',1,sense)))
return(ret);
- if(p)memcpy(p,d->private->sg_buffer,sectors*CD_FRAMESIZE_RAW);
+ if(p)memcpy(p,d->private_data->sg_buffer,sectors*CD_FRAMESIZE_RAW);
return(0);
}
@@ -978,7 +978,7 @@ static int i_read_mmc3 (cdrom_drive *d, void *p, long begin, long sectors, unsig
cmd[8] = sectors;
if((ret=handle_scsi_cmd(d,cmd,12,0,sectors * CD_FRAMESIZE_RAW,'\177',1,sense)))
return(ret);
- if(p)memcpy(p,d->private->sg_buffer,sectors*CD_FRAMESIZE_RAW);
+ if(p)memcpy(p,d->private_data->sg_buffer,sectors*CD_FRAMESIZE_RAW);
return(0);
}
@@ -992,7 +992,7 @@ static int i_read_mmc3B (cdrom_drive *d, void *p, long begin, long sectors, unsi
cmd[8] = sectors;
if((ret=handle_scsi_cmd(d,cmd,12,0,sectors * CD_FRAMESIZE_RAW,'\177',1,sense)))
return(ret);
- if(p)memcpy(p,d->private->sg_buffer,sectors*CD_FRAMESIZE_RAW);
+ if(p)memcpy(p,d->private_data->sg_buffer,sectors*CD_FRAMESIZE_RAW);
return(0);
}
@@ -1026,7 +1026,7 @@ static int i_read_msf (cdrom_drive *d, void *p, long begin, long sectors, unsign
if((ret=handle_scsi_cmd(d,cmd,12,0,sectors * CD_FRAMESIZE_RAW,'\177',1,sense)))
return(ret);
- if(p)memcpy(p,d->private->sg_buffer,sectors*CD_FRAMESIZE_RAW);
+ if(p)memcpy(p,d->private_data->sg_buffer,sectors*CD_FRAMESIZE_RAW);
return(0);
}
@@ -1039,7 +1039,7 @@ static int i_read_msf2 (cdrom_drive *d, void *p, long begin, long sectors, unsig
if((ret=handle_scsi_cmd(d,cmd,12,0,sectors * CD_FRAMESIZE_RAW,'\177',1,sense)))
return(ret);
- if(p)memcpy(p,d->private->sg_buffer,sectors*CD_FRAMESIZE_RAW);
+ if(p)memcpy(p,d->private_data->sg_buffer,sectors*CD_FRAMESIZE_RAW);
return(0);
}
@@ -1052,7 +1052,7 @@ static int i_read_msf3 (cdrom_drive *d, void *p, long begin, long sectors, unsig
if((ret=handle_scsi_cmd(d,cmd,12,0,sectors * CD_FRAMESIZE_RAW,'\177',1,sense)))
return(ret);
- if(p)memcpy(p,d->private->sg_buffer,sectors*CD_FRAMESIZE_RAW);
+ if(p)memcpy(p,d->private_data->sg_buffer,sectors*CD_FRAMESIZE_RAW);
return(0);
}
@@ -1275,7 +1275,7 @@ long scsi_read_msf3 (cdrom_drive *d, void *p, long begin,
static int count_2352_bytes(cdrom_drive *d){
long i;
for(i=2351;i>=0;i--)
- if(d->private->sg_buffer[i]!=(unsigned char)'\177')
+ if(d->private_data->sg_buffer[i]!=(unsigned char)'\177')
return(((i+3)>>2)<<2);
return(0);
@@ -1284,7 +1284,7 @@ static int count_2352_bytes(cdrom_drive *d){
static int verify_nonzero(cdrom_drive *d){
long i,flag=0;
for(i=0;i<2352;i++)
- if(d->private->sg_buffer[i]!=0){
+ if(d->private_data->sg_buffer[i]!=0){
flag=1;
break;
}
@@ -1625,7 +1625,7 @@ static int check_mmc(cdrom_drive *d){
d->is_mmc=0;
if(mode_sense(d,22,0x2A)==0){
- b=d->private->sg_buffer;
+ b=d->private_data->sg_buffer;
b+=b[3]+4;
if((b[0]&0x3F)==0x2A){
@@ -1673,7 +1673,7 @@ unsigned char *scsi_inquiry(cdrom_drive *d){
cderror(d,"008: Unable to identify CDROM model\n");
return(NULL);
}
- return (d->private->sg_buffer);
+ return (d->private_data->sg_buffer);
}
int scsi_init_drive(cdrom_drive *d){
@@ -1742,8 +1742,8 @@ int scsi_init_drive(cdrom_drive *d){
check_cache(d);
d->error_retry=1;
- d->private->sg_hd=realloc(d->private->sg_hd,d->nsectors*CD_FRAMESIZE_RAW + SG_OFF + 128);
- d->private->sg_buffer=((unsigned char *)d->private->sg_hd)+SG_OFF;
+ d->private_data->sg_hd=realloc(d->private_data->sg_hd,d->nsectors*CD_FRAMESIZE_RAW + SG_OFF + 128);
+ d->private_data->sg_buffer=((unsigned char *)d->private_data->sg_hd)+SG_OFF;
d->report_all=1;
return(0);
}
diff --git a/interface/test_interface.c b/interface/test_interface.c
index 11bec25..ad7e992 100644
--- a/interface/test_interface.c
+++ b/interface/test_interface.c
@@ -66,9 +66,9 @@ static long test_read(cdrom_drive *d, void *p, long begin, long sectors){
if(!fd)fd=fdopen(d->cdda_fd,"r");
if(begin<lastread)
- d->private->last_milliseconds=20;
+ d->private_data->last_milliseconds=20;
else
- d->private->last_milliseconds=sectors;
+ d->private_data->last_milliseconds=sectors;
#ifdef CDDA_TEST_UNDERRUN
sectors-=1;

View File

@ -1,25 +0,0 @@
From: Monty <paranoia@xiph.org>
Date: Tue, 30 Jan 2018 13:51:00 +0900
Subject: Changeset 15356: Fix a really stupid oversight that should have been
tested:
forcing a drive/host endian mismatch within the interface lib.
Does not check for null buff before trying a byteswap
(Closes: #499716, #506337, #507795, #509762).
---
interface/interface.c | 2 +-
1 file changed, 1 insertion(+), 1 deletion(-)
diff --git a/interface/interface.c b/interface/interface.c
index cce83a4..30bffb0 100644
--- a/interface/interface.c
+++ b/interface/interface.c
@@ -118,7 +118,7 @@ long cdda_read_timed(cdrom_drive *d, void *buffer, long beginsector, long sector
if(d->bigendianp==-1) /* not determined yet */
d->bigendianp=data_bigendianp(d);
- if(d->bigendianp!=bigendianp()){
+ if(buffer && d->bigendianp!=bigendianp()){
int i;
u_int16_t *p=(u_int16_t *)buffer;
long els=sectors*CD_FRAMESIZE_RAW/2;

File diff suppressed because it is too large Load Diff

File diff suppressed because it is too large Load Diff

View File

@ -1,21 +0,0 @@
From: Optical Media Tools Team <pkg-opt-media-team@lists.alioth.debian.org>
Date: Tue, 30 Jan 2018 13:51:00 +0900
Subject: jpmanfix
---
cdparanoia.1.jp | 2 +-
1 file changed, 1 insertion(+), 1 deletion(-)
diff --git a/cdparanoia.1.jp b/cdparanoia.1.jp
index 97d205f..07545ad 100644
--- a/cdparanoia.1.jp
+++ b/cdparanoia.1.jp
@@ -151,7 +151,7 @@ CD
.TP
.B \-Z --disable-paranoia
データ照合と訂正機能を
-.b 全て
+.B 全て
無効にします。-Z オプションを用いると、cdparanoia は
オーバーラップの設定が 0 である cdda2wav と全く同じようにデータの
読み取りを行います。

View File

@ -1,68 +0,0 @@
From: Optical Media Tools Team <pkg-opt-media-team@lists.alioth.debian.org>
Date: Tue, 30 Jan 2018 13:51:00 +0900
Subject: New option "--force-progress-bar"
---
main.c | 13 ++++++++++---
1 file changed, 10 insertions(+), 3 deletions(-)
diff --git a/main.c b/main.c
index ed485d2..d7b4b09 100644
--- a/main.c
+++ b/main.c
@@ -213,6 +213,8 @@ VERSION"\n"
" -q --quiet : quiet operation\n"
" -e --stderr-progress : force output of progress information to\n"
" stderr (for wrapper scripts)\n"
+" -E --force-progress-bar : force output of progress bar even if\n"
+" stderr is not a terminal\n"
" -l --log-summary [<file>] : save result summary to file, default\n"
" filename cdparanoia.log\n"
" -L --log-debug [<file>] : save detailed device autosense and\n"
@@ -341,6 +343,7 @@ VERSION"\n"
long callbegin;
long callend;
long callscript=0;
+long force_progress_bar=0;
static char *callback_strings[16]={"wrote",
"finished",
@@ -407,13 +410,13 @@ static void callback(long inpos, int function){
}
}
- if(!quiet){
+ if(force_progress_bar || !quiet){
long test;
osector=inpos;
sector=inpos/CD_FRAMEWORDS;
if(printit==-1){
- if(isatty(STDERR_FILENO)){
+ if(force_progress_bar || isatty(STDERR_FILENO)){
printit=1;
}else{
printit=0;
@@ -607,10 +610,11 @@ static void callback(long inpos, int function){
memset(dispcache,' ',graph);
}
-const char *optstring = "escCn:o:O:d:g:k:S:prRwafvqVQhZz::YXWBi:Tt:l::L::A";
+const char *optstring = "eEscCn:o:O:d:g:k:S:prRwafvqVQhZz::YXWBi:Tt:l::L::A";
struct option options [] = {
{"stderr-progress",no_argument,NULL,'e'},
+ {"force-progress-bar",no_argument,NULL,'E'},
{"search-for-drive",no_argument,NULL,'s'},
{"force-cdrom-little-endian",no_argument,NULL,'c'},
{"force-cdrom-big-endian",no_argument,NULL,'C'},
@@ -786,6 +790,9 @@ int main(int argc,char *argv[]){
callscript=1;
fprintf(stderr,"Sending all callbacks to stderr for wrapper script\n");
break;
+ case 'E':
+ force_progress_bar=1;
+ break;
case 'V':
fprintf(stderr,VERSION);
fprintf(stderr,"\n");

View File

@ -1,9 +0,0 @@
01-typos-and-spelling.patch
02-ide-devices.patch
03-gcc4.3.patch
04-endian.patch
05-kfreebsd.patch
06-autoconf.patch
07-jpmanfix.patch
cdparanoia-force-progress-bar.diff
0009-dh-autoconf-generate-config-files.patch

View File

@ -1 +1 @@
3.0 (quilt)
3.0 (native)
diff --git a/main.c b/main.c
index 664acac..24d6ca3 100644
--- a/main.c
+++ b/main.c
@@ -51,7 +51,7 @@ static long parse_offset(cdrom_drive *d, char *offset, int begin){
if(offset==NULL)return(-1);
/* seperate track from time offset */
temp=strchr(offset,']');
if(temp){
*temp='\0';
@@ -221,14 +221,14 @@ VERSION"\n"
" -V --version : print version info and quit\n"
" -Q --query : autosense drive, query disc and quit\n"
" -B --batch : 'batch' mode (saves each track to a\n"
-" seperate file.\n"
+" separate file.\n"
" -s --search-for-drive : do an exhaustive search for drive\n"
" -h --help : print help\n\n"
-" -p --output-raw : output raw 16 bit PCM in host byte \n"
+" -p --output-raw : output raw 16-bit PCM in host byte \n"
" order\n"
-" -r --output-raw-little-endian : output raw 16 bit little-endian PCM\n"
-" -R --output-raw-big-endian : output raw 16 bit big-endian PCM\n"
+" -r --output-raw-little-endian : output raw 16-bit little-endian PCM\n"
+" -R --output-raw-big-endian : output raw 16-bit big-endian PCM\n"
" -w --output-wav : output as WAV file (default)\n"
" -f --output-aiff : output as AIFF file\n"
" -a --output-aifc : output as AIFF-C file\n\n"
@@ -295,7 +295,7 @@ VERSION"\n"
" 1[ww:xx:yy.zz]-2[aa:bb:cc.dd] \n\n"
"Here, 1 and 2 are track numbers; the numbers in brackets provide a\n"
-"finer grained offset within a particular track. [aa:bb:cc.dd] is in\n"
+"finer-grained offset within a particular track. [aa:bb:cc.dd] is in\n"
"hours/minutes/seconds/sectors format. Zero fields need not be\n"
"specified: [::20], [:20], [20], [20.], etc, would be interpreted as\n"
"twenty seconds, [10:] would be ten minutes, [.30] would be thirty\n"
@@ -303,7 +303,7 @@ VERSION"\n"
"When only a single offset is supplied, it is interpreted as a starting\n"
"offset and ripping will continue to the end of he track. If a single\n"
-"offset is preceeded or followed by a hyphen, the implicit missing\n"
+"offset is preceded or followed by a hyphen, the implicit missing\n"
"offset is taken to be the start or end of the disc, respectively. Thus:\n\n"
" 1:[20.35] Specifies ripping from track 1, second 20, sector 35 to \n"
@@ -320,15 +320,18 @@ VERSION"\n"
" 2-4 Specifies ripping from the beginning of track two to the\n"
" end of track 4.\n\n"
-"Don't forget to protect square brackets and preceeding hyphens from\n"
+"Don't forget to protect square brackets and preceding hyphens from\n"
"the shell...\n\n"
"A few examples, protected from the shell:\n"
+"Don't forget to protect square brackets from the shell...\n\n"
+
+"A few examples, protected from the shell where appropriate:\n"
" A) query only with exhaustive search for a drive and full reporting\n"
" of autosense:\n"
" cdparanoia -vsQ\n\n"
-" B) extract up to and including track 3, putting each track in a seperate\n"
+" B) extract up to and including track 3, putting each track in a separate\n"
" file:\n"
-" cdparanoia -B -- \"-3\"\n\n"
+" cdparanoia -B -- -3\n\n"
" C) extract from track 1, time 0:30.12 to 1:10.00:\n"
" cdparanoia \"1[:30.12]-1[1:10]\"\n\n"
@@ -726,7 +729,7 @@ int main(int argc,char *argv[]){
break;
case 'g':
if(force_cooked_device){
- report("-g option incompatable with -k\n");
+ report("-g option incompatible with -k\n");
exit(1);
}
force_cooked_device=NULL;
@@ -735,7 +738,7 @@ int main(int argc,char *argv[]){
break;
case 'k':
if(force_generic_device || force_cdrom_device){
- report("-k option incompatable with -d and -g\n");
+ report("-k option incompatible with -d and -g\n");
exit(1);
}
if(force_cooked_device)free(force_cooked_device);

View File

@ -1,25 +0,0 @@
From: Steven Ihde <sihde@cs.stanford.edu>
Date: Tue, 30 Jan 2018 13:51:00 +0900
Subject: Adds support for higher ide devices.
---
interface/scan_devices.c | 6 ++++++
1 file changed, 6 insertions(+)
@@ -51,7 +51,7 @@ static long parse_offset(cdrom_drive *d, char *offset, int begin){
if(offset==NULL)return(-1);
- /* seperate track from time offset */
+ /* separate track from time offset */
temp=strchr(offset,']');
if(temp){